import unittest
from grammarcorrector import GrammarCorrector

class TestGrammarCorrector(unittest.TestCase):
    def setUp(self):
        self.corrector = GrammarCorrector()

    def test_correction(self):
        input_text = "This are bad grammar sentence."
        expected_output = "This is a bad grammar sentence."
        self.assertEqual(self.corrector.correct(input_text), expected_output)

if __name__ == "__main__":
    unittest.main()



from setuptools import setup, find_packages

setup(
    name="grammarcorrector",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "replicate>=1.0.4",
    ],
    author="D.",
    author_email="hello@world.com",
    description="A Python package for grammar correction using a remote model on Replicate.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/aaurelions/grammarcorrector",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)



import replicate

class GrammarCorrector:
    def __init__(self):
        self.model = "aaurelions/t5-grammar-corrector:4502e6d4714acf2152cd417a63792f3a59e983d440b9aa4c8df9b5d84a72931f"

    def correct(self, text):
        output = replicate.run(
            self.model,
            input={"text": text}
        )
        return output
